import dotenv from 'dotenv';
import { Subject } from 'rxjs';
import { WrappedMessage } from '../utils/message.ordering';
import ConsoleLogger from '../utils/log.utils';
import { AdapterBase } from '../base/adapter.base';
import { FisMessage, TransmissionRole, Transport, TransportMessage, TransportServiceInterface } from '../interface/interface';

dotenv.config();
/* This transport manager will be instantiating the necessary transport to deal with tranmission and receiving from different receivers
So how?: */
export class TransmitterAdapter extends AdapterBase {
    private console!: ConsoleLogger

    constructor(adapterId: string, adapterType: Transport, transportService: TransportServiceInterface) {
        super()
        this.setAdapterProfile(adapterId, adapterType, 'Transmitter')
        this.console = new ConsoleLogger(`${adapterType}TransmitterAdapter`, ['adapter'])
        this.transportService = transportService

        this.console.log({ message: `Contructing TransmitterAdapter for client: ${adapterId}` })
    }

    emit(message: WrappedMessage): void {
        // logic here
        this.console.log({ message: `Emitting: ${(message.payload as FisMessage).header.messageID} to ${this.adapterId}` })
        this.transportService.emit({
            id: this.adapterId,
            transport: this.transport,
            target: this.adapterId, // this should be directed to the channel/client established. Make sure this is right
            payload: message
        } as TransportMessage)
    }

    setAdapterProfile(id: string, adapterType: Transport, role: TransmissionRole): void {
        this.adapterId = id
        this.transport = adapterType
        this.role = role
    }

}


